@@ -11,19 +11,39 @@ use strict;
 use warnings;
 
 package HTML::FromANSI::Tiny;
-# git description: v0.102-2-ge6a677d
-$HTML::FromANSI::Tiny::VERSION = '0.103';
-BEGIN {
-  $HTML::FromANSI::Tiny::AUTHORITY = 'cpan:RWSTAUNER';
-}
-# ABSTRACT: Easily convert colored command line output to HTML
+# git description: v0.103-6-g909cd91
 
+our $AUTHORITY = 'cpan:RWSTAUNER';
+# ABSTRACT: Easily convert colored command line output to HTML
+$HTML::FromANSI::Tiny::VERSION = '0.104';
 our @COLORS = map { "#$_" }
 qw(
   000  f33  2c2  bb0  55c  d3d  0cc  bbb
   555  f66  6d6  dd6  99f  f6f  6dd  fff
 );
 
+# 256 palette.
+our @COLORS256 = (
+  # First 16 are the same.
+  @COLORS,
+  # rgbXYZ
+  do {
+    my @c;
+    for my $r ( 0 .. 5 ){
+      for my $g ( 0 .. 5 ){
+        for my $b ( 0 .. 5 ){
+          push @c, '#' . join('', map { sprintf '%02x', $_ * (255/5) } ($r, $g, $b));
+        }
+      }
+    }
+    @c; # return
+  },
+  # "nearly black to nearly white"
+  (map { '#' . join('', (sprintf '%02x', ($_ + 1) * 10) x 3) } (0 .. 23)),
+);
+
+our @ALLCOLORS = (@COLORS, @COLORS256);
+
 
 sub new {
   my $class = shift;
@@ -88,11 +108,11 @@ sub _css_class_attr {
     {
       my $i = 0;
       foreach my $fg ( $parser->foreground_colors ){
-        $styles->{$fg} = { color => $COLORS[$i++] };
+        $styles->{$fg} = { color => $ALLCOLORS[$i++] };
       }
       $i = 0;
       foreach my $bg ( $parser->background_colors ){
-        $styles->{$bg} = { 'background-color' => $COLORS[$i++] };
+        $styles->{$bg} = { 'background-color' => $ALLCOLORS[$i++] };
       }
     }
 
@@ -181,9 +201,9 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Randy Stauner ACKNOWLEDGEMENTS inline hashrefs Stephen Thirlwall
-<sdt@cpan.org> html cpan testmatrix url annocpan anno bugtracker rt cpants
-kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords Randy Stauner ACKNOWLEDGEMENTS inline hashrefs html customizable cpan
+testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto
+metadata placeholders metacpan
 
 =head1 NAME
 
@@ -191,7 +211,7 @@ HTML::FromANSI::Tiny - Easily convert colored command line output to HTML
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
@@ -454,7 +474,7 @@ L<http://metacpan.org/release/HTML-FromANSI-Tiny>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-html-fromansi-tiny at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-FromANSI-Tiny>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=HTML-FromANSI-Tiny>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -470,6 +490,8 @@ Randy Stauner <rwstauner@cpan.org>
 
 =head1 CONTRIBUTOR
 
+=for stopwords Stephen Thirlwall
+
 Stephen Thirlwall <sdt@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
